{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.CleSolver
       (
         CleSolver,
         CleSolverClass(..),
         cleSolver,
         cleSolver_clone,
         cleSolver_doc,
         cleSolver_hasPlugin,
         cleSolver_loadPlugin,
         cleSolver_printStats,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__CONSTRUCTOR" c_casadi__CleSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr CleSolver')
casadi__CleSolver__CONSTRUCTOR
  :: IO CleSolver
casadi__CleSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver :: IO CleSolver
cleSolver = casadi__CleSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__clone" c_casadi__CleSolver__clone
  :: Ptr (Ptr StdString) -> Ptr CleSolver' -> IO (Ptr CleSolver')
casadi__CleSolver__clone
  :: CleSolver -> IO CleSolver
casadi__CleSolver__clone x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__clone errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver_clone :: CleSolverClass a => a -> IO CleSolver
cleSolver_clone x = casadi__CleSolver__clone (castCleSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__doc" c_casadi__CleSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__CleSolver__doc
  :: String -> IO String
casadi__CleSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver_doc :: String -> IO String
cleSolver_doc = casadi__CleSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__hasPlugin" c_casadi__CleSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__CleSolver__hasPlugin
  :: String -> IO Bool
casadi__CleSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver_hasPlugin :: String -> IO Bool
cleSolver_hasPlugin = casadi__CleSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__loadPlugin" c_casadi__CleSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__CleSolver__loadPlugin
  :: String -> IO ()
casadi__CleSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver_loadPlugin :: String -> IO ()
cleSolver_loadPlugin = casadi__CleSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__CleSolver__printStats" c_casadi__CleSolver__printStats
  :: Ptr (Ptr StdString) -> Ptr CleSolver' -> IO ()
casadi__CleSolver__printStats
  :: CleSolver -> IO ()
casadi__CleSolver__printStats x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__CleSolver__printStats errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
cleSolver_printStats :: CleSolverClass a => a -> IO ()
cleSolver_printStats x = casadi__CleSolver__printStats (castCleSolver x)

