{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.LrDleSolver
       (
         LrDleSolver,
         LrDleSolverClass(..),
         lrDleSolver,
         lrDleSolver_clone,
         lrDleSolver_doc,
         lrDleSolver_hasPlugin,
         lrDleSolver_loadPlugin,
         lrDleSolver_printStats,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__CONSTRUCTOR" c_casadi__LrDleSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr LrDleSolver')
casadi__LrDleSolver__CONSTRUCTOR
  :: IO LrDleSolver
casadi__LrDleSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver :: IO LrDleSolver
lrDleSolver = casadi__LrDleSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__clone" c_casadi__LrDleSolver__clone
  :: Ptr (Ptr StdString) -> Ptr LrDleSolver' -> IO (Ptr LrDleSolver')
casadi__LrDleSolver__clone
  :: LrDleSolver -> IO LrDleSolver
casadi__LrDleSolver__clone x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__clone errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver_clone :: LrDleSolverClass a => a -> IO LrDleSolver
lrDleSolver_clone x = casadi__LrDleSolver__clone (castLrDleSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__doc" c_casadi__LrDleSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__LrDleSolver__doc
  :: String -> IO String
casadi__LrDleSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver_doc :: String -> IO String
lrDleSolver_doc = casadi__LrDleSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__hasPlugin" c_casadi__LrDleSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__LrDleSolver__hasPlugin
  :: String -> IO Bool
casadi__LrDleSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver_hasPlugin :: String -> IO Bool
lrDleSolver_hasPlugin = casadi__LrDleSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__loadPlugin" c_casadi__LrDleSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__LrDleSolver__loadPlugin
  :: String -> IO ()
casadi__LrDleSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver_loadPlugin :: String -> IO ()
lrDleSolver_loadPlugin = casadi__LrDleSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__LrDleSolver__printStats" c_casadi__LrDleSolver__printStats
  :: Ptr (Ptr StdString) -> Ptr LrDleSolver' -> IO ()
casadi__LrDleSolver__printStats
  :: LrDleSolver -> IO ()
casadi__LrDleSolver__printStats x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__LrDleSolver__printStats errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
lrDleSolver_printStats :: LrDleSolverClass a => a -> IO ()
lrDleSolver_printStats x = casadi__LrDleSolver__printStats (castLrDleSolver x)

