{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.NlpSolver
       (
         NlpSolver,
         NlpSolverClass(..),
         nlpSolver__0,
         nlpSolver__1,
         nlpSolver_doc,
         nlpSolver_getReducedHessian,
         nlpSolver_getReportConstraints,
         nlpSolver_gradF,
         nlpSolver_hasPlugin,
         nlpSolver_hessLag,
         nlpSolver_jacG,
         nlpSolver_joinFG,
         nlpSolver_loadPlugin,
         nlpSolver_nlp,
         nlpSolver_reportConstraints,
         nlpSolver_setOptionsFromFile,
         nlpSolver_setQPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__CONSTRUCTOR__0" c_casadi__NlpSolver__CONSTRUCTOR__0
  :: Ptr (Ptr StdString) -> Ptr StdString -> Ptr Function' -> IO (Ptr NlpSolver')
casadi__NlpSolver__CONSTRUCTOR__0
  :: String -> Function -> IO NlpSolver
casadi__NlpSolver__CONSTRUCTOR__0 x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__CONSTRUCTOR__0 errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver__0 :: String -> Function -> IO NlpSolver
nlpSolver__0 = casadi__NlpSolver__CONSTRUCTOR__0


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__CONSTRUCTOR__1" c_casadi__NlpSolver__CONSTRUCTOR__1
  :: Ptr (Ptr StdString) -> IO (Ptr NlpSolver')
casadi__NlpSolver__CONSTRUCTOR__1
  :: IO NlpSolver
casadi__NlpSolver__CONSTRUCTOR__1  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__CONSTRUCTOR__1 errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver__1 :: IO NlpSolver
nlpSolver__1 = casadi__NlpSolver__CONSTRUCTOR__1


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__doc" c_casadi__NlpSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__NlpSolver__doc
  :: String -> IO String
casadi__NlpSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_doc :: String -> IO String
nlpSolver_doc = casadi__NlpSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__getReducedHessian" c_casadi__NlpSolver__getReducedHessian
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr DMatrix')
casadi__NlpSolver__getReducedHessian
  :: NlpSolver -> IO DMatrix
casadi__NlpSolver__getReducedHessian x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__getReducedHessian errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_getReducedHessian :: NlpSolverClass a => a -> IO DMatrix
nlpSolver_getReducedHessian x = casadi__NlpSolver__getReducedHessian (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__getReportConstraints" c_casadi__NlpSolver__getReportConstraints
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr StdString)
casadi__NlpSolver__getReportConstraints
  :: NlpSolver -> IO String
casadi__NlpSolver__getReportConstraints x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__getReportConstraints errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_getReportConstraints :: NlpSolverClass a => a -> IO String
nlpSolver_getReportConstraints x = casadi__NlpSolver__getReportConstraints (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__gradF" c_casadi__NlpSolver__gradF
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr Function')
casadi__NlpSolver__gradF
  :: NlpSolver -> IO Function
casadi__NlpSolver__gradF x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__gradF errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_gradF :: NlpSolverClass a => a -> IO Function
nlpSolver_gradF x = casadi__NlpSolver__gradF (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__hasPlugin" c_casadi__NlpSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__NlpSolver__hasPlugin
  :: String -> IO Bool
casadi__NlpSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_hasPlugin :: String -> IO Bool
nlpSolver_hasPlugin = casadi__NlpSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__hessLag" c_casadi__NlpSolver__hessLag
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr Function')
casadi__NlpSolver__hessLag
  :: NlpSolver -> IO Function
casadi__NlpSolver__hessLag x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__hessLag errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_hessLag :: NlpSolverClass a => a -> IO Function
nlpSolver_hessLag x = casadi__NlpSolver__hessLag (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__jacG" c_casadi__NlpSolver__jacG
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr Function')
casadi__NlpSolver__jacG
  :: NlpSolver -> IO Function
casadi__NlpSolver__jacG x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__jacG errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_jacG :: NlpSolverClass a => a -> IO Function
nlpSolver_jacG x = casadi__NlpSolver__jacG (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__joinFG" c_casadi__NlpSolver__joinFG
  :: Ptr (Ptr StdString) -> Ptr Function' -> Ptr Function' -> IO (Ptr Function')
casadi__NlpSolver__joinFG
  :: Function -> Function -> IO Function
casadi__NlpSolver__joinFG x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__joinFG errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_joinFG :: Function -> Function -> IO Function
nlpSolver_joinFG = casadi__NlpSolver__joinFG


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__loadPlugin" c_casadi__NlpSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__NlpSolver__loadPlugin
  :: String -> IO ()
casadi__NlpSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_loadPlugin :: String -> IO ()
nlpSolver_loadPlugin = casadi__NlpSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__nlp" c_casadi__NlpSolver__nlp
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO (Ptr Function')
casadi__NlpSolver__nlp
  :: NlpSolver -> IO Function
casadi__NlpSolver__nlp x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__nlp errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_nlp :: NlpSolverClass a => a -> IO Function
nlpSolver_nlp x = casadi__NlpSolver__nlp (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__reportConstraints" c_casadi__NlpSolver__reportConstraints
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO ()
casadi__NlpSolver__reportConstraints
  :: NlpSolver -> IO ()
casadi__NlpSolver__reportConstraints x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__reportConstraints errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_reportConstraints :: NlpSolverClass a => a -> IO ()
nlpSolver_reportConstraints x = casadi__NlpSolver__reportConstraints (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__setOptionsFromFile" c_casadi__NlpSolver__setOptionsFromFile
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> Ptr StdString -> IO ()
casadi__NlpSolver__setOptionsFromFile
  :: NlpSolver -> String -> IO ()
casadi__NlpSolver__setOptionsFromFile x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__setOptionsFromFile errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_setOptionsFromFile :: NlpSolverClass a => a -> String -> IO ()
nlpSolver_setOptionsFromFile x = casadi__NlpSolver__setOptionsFromFile (castNlpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__NlpSolver__setQPOptions" c_casadi__NlpSolver__setQPOptions
  :: Ptr (Ptr StdString) -> Ptr NlpSolver' -> IO ()
casadi__NlpSolver__setQPOptions
  :: NlpSolver -> IO ()
casadi__NlpSolver__setQPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__NlpSolver__setQPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
nlpSolver_setQPOptions :: NlpSolverClass a => a -> IO ()
nlpSolver_setQPOptions x = casadi__NlpSolver__setQPOptions (castNlpSolver x)

