{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.QcqpSolver
       (
         QcqpSolver,
         QcqpSolverClass(..),
         qcqpSolver,
         qcqpSolver_doc,
         qcqpSolver_hasPlugin,
         qcqpSolver_loadPlugin,
         qcqpSolver_setQPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__QcqpSolver__CONSTRUCTOR" c_casadi__QcqpSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr QcqpSolver')
casadi__QcqpSolver__CONSTRUCTOR
  :: IO QcqpSolver
casadi__QcqpSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QcqpSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qcqpSolver :: IO QcqpSolver
qcqpSolver = casadi__QcqpSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__QcqpSolver__doc" c_casadi__QcqpSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__QcqpSolver__doc
  :: String -> IO String
casadi__QcqpSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QcqpSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qcqpSolver_doc :: String -> IO String
qcqpSolver_doc = casadi__QcqpSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__QcqpSolver__hasPlugin" c_casadi__QcqpSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__QcqpSolver__hasPlugin
  :: String -> IO Bool
casadi__QcqpSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QcqpSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qcqpSolver_hasPlugin :: String -> IO Bool
qcqpSolver_hasPlugin = casadi__QcqpSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__QcqpSolver__loadPlugin" c_casadi__QcqpSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__QcqpSolver__loadPlugin
  :: String -> IO ()
casadi__QcqpSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QcqpSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qcqpSolver_loadPlugin :: String -> IO ()
qcqpSolver_loadPlugin = casadi__QcqpSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__QcqpSolver__setQPOptions" c_casadi__QcqpSolver__setQPOptions
  :: Ptr (Ptr StdString) -> Ptr QcqpSolver' -> IO ()
casadi__QcqpSolver__setQPOptions
  :: QcqpSolver -> IO ()
casadi__QcqpSolver__setQPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QcqpSolver__setQPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qcqpSolver_setQPOptions :: QcqpSolverClass a => a -> IO ()
qcqpSolver_setQPOptions x = casadi__QcqpSolver__setQPOptions (castQcqpSolver x)

