{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.QpSolver
       (
         QpSolver,
         QpSolverClass(..),
         qpSolver,
         qpSolver_doc,
         qpSolver_generateNativeCode,
         qpSolver_hasPlugin,
         qpSolver_loadPlugin,
         qpSolver_setLPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__CONSTRUCTOR" c_casadi__QpSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr QpSolver')
casadi__QpSolver__CONSTRUCTOR
  :: IO QpSolver
casadi__QpSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver :: IO QpSolver
qpSolver = casadi__QpSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__doc" c_casadi__QpSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__QpSolver__doc
  :: String -> IO String
casadi__QpSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_doc :: String -> IO String
qpSolver_doc = casadi__QpSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__generateNativeCode" c_casadi__QpSolver__generateNativeCode
  :: Ptr (Ptr StdString) -> Ptr QpSolver' -> Ptr StdString -> IO ()
casadi__QpSolver__generateNativeCode
  :: QpSolver -> String -> IO ()
casadi__QpSolver__generateNativeCode x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__generateNativeCode errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_generateNativeCode :: QpSolverClass a => a -> String -> IO ()
qpSolver_generateNativeCode x = casadi__QpSolver__generateNativeCode (castQpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__hasPlugin" c_casadi__QpSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__QpSolver__hasPlugin
  :: String -> IO Bool
casadi__QpSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_hasPlugin :: String -> IO Bool
qpSolver_hasPlugin = casadi__QpSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__loadPlugin" c_casadi__QpSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__QpSolver__loadPlugin
  :: String -> IO ()
casadi__QpSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_loadPlugin :: String -> IO ()
qpSolver_loadPlugin = casadi__QpSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__QpSolver__setLPOptions" c_casadi__QpSolver__setLPOptions
  :: Ptr (Ptr StdString) -> Ptr QpSolver' -> IO ()
casadi__QpSolver__setLPOptions
  :: QpSolver -> IO ()
casadi__QpSolver__setLPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__QpSolver__setLPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
qpSolver_setLPOptions :: QpSolverClass a => a -> IO ()
qpSolver_setLPOptions x = casadi__QpSolver__setLPOptions (castQpSolver x)

