{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.SdpSolver
       (
         SdpSolver,
         SdpSolverClass(..),
         sdpSolver,
         sdpSolver_doc,
         sdpSolver_hasPlugin,
         sdpSolver_loadPlugin,
         sdpSolver_setSOCPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__SdpSolver__CONSTRUCTOR" c_casadi__SdpSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr SdpSolver')
casadi__SdpSolver__CONSTRUCTOR
  :: IO SdpSolver
casadi__SdpSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SdpSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver :: IO SdpSolver
sdpSolver = casadi__SdpSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__SdpSolver__doc" c_casadi__SdpSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__SdpSolver__doc
  :: String -> IO String
casadi__SdpSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SdpSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_doc :: String -> IO String
sdpSolver_doc = casadi__SdpSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__SdpSolver__hasPlugin" c_casadi__SdpSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__SdpSolver__hasPlugin
  :: String -> IO Bool
casadi__SdpSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SdpSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_hasPlugin :: String -> IO Bool
sdpSolver_hasPlugin = casadi__SdpSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__SdpSolver__loadPlugin" c_casadi__SdpSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__SdpSolver__loadPlugin
  :: String -> IO ()
casadi__SdpSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SdpSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_loadPlugin :: String -> IO ()
sdpSolver_loadPlugin = casadi__SdpSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__SdpSolver__setSOCPOptions" c_casadi__SdpSolver__setSOCPOptions
  :: Ptr (Ptr StdString) -> Ptr SdpSolver' -> IO ()
casadi__SdpSolver__setSOCPOptions
  :: SdpSolver -> IO ()
casadi__SdpSolver__setSOCPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SdpSolver__setSOCPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sdpSolver_setSOCPOptions :: SdpSolverClass a => a -> IO ()
sdpSolver_setSOCPOptions x = casadi__SdpSolver__setSOCPOptions (castSdpSolver x)

