{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.SharedObject
       (
         SharedObject,
         SharedObjectClass(..),
         sharedObject_assertInit,
         sharedObject_getDescription,
         sharedObject_getRepresentation,
         sharedObject_init__0,
         sharedObject_init__1,
         sharedObject_isInit,
         sharedObject_isNull,
         sharedObject_makeUnique__0,
         sharedObject_makeUnique__1,
         sharedObject_printPtr,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__assertInit" c_casadi__SharedObject__assertInit
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO ()
casadi__SharedObject__assertInit
  :: SharedObject -> IO ()
casadi__SharedObject__assertInit x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__assertInit errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_assertInit :: SharedObjectClass a => a -> IO ()
sharedObject_assertInit x = casadi__SharedObject__assertInit (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__init__0" c_casadi__SharedObject__init__0
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO ()
casadi__SharedObject__init__0
  :: SharedObject -> IO ()
casadi__SharedObject__init__0 x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__init__0 errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_init__0 :: SharedObjectClass a => a -> IO ()
sharedObject_init__0 x = casadi__SharedObject__init__0 (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__init__1" c_casadi__SharedObject__init__1
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> CInt -> IO ()
casadi__SharedObject__init__1
  :: SharedObject -> Bool -> IO ()
casadi__SharedObject__init__1 x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__init__1 errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_init__1 :: SharedObjectClass a => a -> Bool -> IO ()
sharedObject_init__1 x = casadi__SharedObject__init__1 (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__isInit" c_casadi__SharedObject__isInit
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO CInt
casadi__SharedObject__isInit
  :: SharedObject -> IO Bool
casadi__SharedObject__isInit x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__isInit errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_isInit :: SharedObjectClass a => a -> IO Bool
sharedObject_isInit x = casadi__SharedObject__isInit (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__isNull" c_casadi__SharedObject__isNull
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO CInt
casadi__SharedObject__isNull
  :: SharedObject -> IO Bool
casadi__SharedObject__isNull x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__isNull errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_isNull :: SharedObjectClass a => a -> IO Bool
sharedObject_isNull x = casadi__SharedObject__isNull (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__makeUnique__0" c_casadi__SharedObject__makeUnique__0
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO ()
casadi__SharedObject__makeUnique__0
  :: SharedObject -> IO ()
casadi__SharedObject__makeUnique__0 x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__makeUnique__0 errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_makeUnique__0 :: SharedObjectClass a => a -> IO ()
sharedObject_makeUnique__0 x = casadi__SharedObject__makeUnique__0 (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__makeUnique__1" c_casadi__SharedObject__makeUnique__1
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> CInt -> IO ()
casadi__SharedObject__makeUnique__1
  :: SharedObject -> Bool -> IO ()
casadi__SharedObject__makeUnique__1 x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__makeUnique__1 errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_makeUnique__1 :: SharedObjectClass a => a -> Bool -> IO ()
sharedObject_makeUnique__1 x = casadi__SharedObject__makeUnique__1 (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__printPtr" c_casadi__SharedObject__printPtr
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO ()
casadi__SharedObject__printPtr
  :: SharedObject -> IO ()
casadi__SharedObject__printPtr x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__printPtr errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_printPtr :: SharedObjectClass a => a -> IO ()
sharedObject_printPtr x = casadi__SharedObject__printPtr (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__getRepresentation" c_casadi__SharedObject__getRepresentation
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO (Ptr StdString)
casadi__SharedObject__getRepresentation
  :: SharedObject -> IO String
casadi__SharedObject__getRepresentation x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__getRepresentation errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_getRepresentation :: SharedObjectClass a => a -> IO String
sharedObject_getRepresentation x = casadi__SharedObject__getRepresentation (castSharedObject x)


-- direct wrapper
foreign import ccall unsafe "casadi__SharedObject__getDescription" c_casadi__SharedObject__getDescription
  :: Ptr (Ptr StdString) -> Ptr SharedObject' -> IO (Ptr StdString)
casadi__SharedObject__getDescription
  :: SharedObject -> IO String
casadi__SharedObject__getDescription x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__SharedObject__getDescription errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
sharedObject_getDescription :: SharedObjectClass a => a -> IO String
sharedObject_getDescription x = casadi__SharedObject__getDescription (castSharedObject x)

