{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Core.Classes.StabilizedQpSolver
       (
         StabilizedQpSolver,
         StabilizedQpSolverClass(..),
         stabilizedQpSolver,
         stabilizedQpSolver_doc,
         stabilizedQpSolver_generateNativeCode,
         stabilizedQpSolver_hasPlugin,
         stabilizedQpSolver_loadPlugin,
         stabilizedQpSolver_setLPOptions,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Core.Data
import Casadi.Core.Enums
-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__CONSTRUCTOR" c_casadi__StabilizedQpSolver__CONSTRUCTOR
  :: Ptr (Ptr StdString) -> IO (Ptr StabilizedQpSolver')
casadi__StabilizedQpSolver__CONSTRUCTOR
  :: IO StabilizedQpSolver
casadi__StabilizedQpSolver__CONSTRUCTOR  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__CONSTRUCTOR errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver :: IO StabilizedQpSolver
stabilizedQpSolver = casadi__StabilizedQpSolver__CONSTRUCTOR


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__doc" c_casadi__StabilizedQpSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__StabilizedQpSolver__doc
  :: String -> IO String
casadi__StabilizedQpSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver_doc :: String -> IO String
stabilizedQpSolver_doc = casadi__StabilizedQpSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__generateNativeCode" c_casadi__StabilizedQpSolver__generateNativeCode
  :: Ptr (Ptr StdString) -> Ptr StabilizedQpSolver' -> Ptr StdString -> IO ()
casadi__StabilizedQpSolver__generateNativeCode
  :: StabilizedQpSolver -> String -> IO ()
casadi__StabilizedQpSolver__generateNativeCode x0 x1 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__generateNativeCode errStrPtrP x0' x1'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver_generateNativeCode :: StabilizedQpSolverClass a => a -> String -> IO ()
stabilizedQpSolver_generateNativeCode x = casadi__StabilizedQpSolver__generateNativeCode (castStabilizedQpSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__hasPlugin" c_casadi__StabilizedQpSolver__hasPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO CInt
casadi__StabilizedQpSolver__hasPlugin
  :: String -> IO Bool
casadi__StabilizedQpSolver__hasPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__hasPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver_hasPlugin :: String -> IO Bool
stabilizedQpSolver_hasPlugin = casadi__StabilizedQpSolver__hasPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__loadPlugin" c_casadi__StabilizedQpSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__StabilizedQpSolver__loadPlugin
  :: String -> IO ()
casadi__StabilizedQpSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver_loadPlugin :: String -> IO ()
stabilizedQpSolver_loadPlugin = casadi__StabilizedQpSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__StabilizedQpSolver__setLPOptions" c_casadi__StabilizedQpSolver__setLPOptions
  :: Ptr (Ptr StdString) -> Ptr StabilizedQpSolver' -> IO ()
casadi__StabilizedQpSolver__setLPOptions
  :: StabilizedQpSolver -> IO ()
casadi__StabilizedQpSolver__setLPOptions x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__StabilizedQpSolver__setLPOptions errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
stabilizedQpSolver_setLPOptions :: StabilizedQpSolverClass a => a -> IO ()
stabilizedQpSolver_setLPOptions x = casadi__StabilizedQpSolver__setLPOptions (castStabilizedQpSolver x)

